@@ -1,27 +1,19 @@
-from .__about__ import (
+from .__about__ import (  # noqa: F401
     __version__,
     __title__,
     __summary__
 )
 
-from .pyonepassword import (   # noqa: F401
-    OP,
+from .pyonepassword import OP  # noqa: F401
+
+from .py_op_exceptions import (  # noqa: F401
     OPLookupException,
     OPSigninException,
     OPNotFoundException,
     OPGetItemException,
     OPGetDocumentException,
-    OPInvalidDocumentException
+    OPInvalidDocumentException,
+    OPSignoutException
 )
 
 from .py_op_exceptions import OPConfigNotFoundException  # noqa: F401
-
-__all__ = [
-    "__version__",
-    "__title__",
-    "__summary__",
-    OP,
-    OPLookupException,
-    OPSigninException,
-    OPNotFoundException
-]
